<?php

namespace Laraauto\Automobile\Policies;

use Litepie\User\Contracts\UserPolicy;
use Laraauto\Automobile\Models\CarModel;

class CarModelPolicy
{

    /**
     * Determine if the given user can view the car_model.
     *
     * @param UserPolicy $user
     * @param CarModel $car_model
     *
     * @return bool
     */
    public function view(UserPolicy $user, CarModel $car_model)
    {
        if ($user->canDo('automobile.car_model.view') && $user->isAdmin()) {
            return true;
        }

        return $car_model->user_id == user_id() && $car_model->user_type == user_type();
    }

    /**
     * Determine if the given user can create a car_model.
     *
     * @param UserPolicy $user
     * @param CarModel $car_model
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('automobile.car_model.create');
    }

    /**
     * Determine if the given user can update the given car_model.
     *
     * @param UserPolicy $user
     * @param CarModel $car_model
     *
     * @return bool
     */
    public function update(UserPolicy $user, CarModel $car_model)
    {
        if ($user->canDo('automobile.car_model.edit') && $user->isAdmin()) {
            return true;
        }

        return $car_model->user_id == user_id() && $car_model->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given car_model.
     *
     * @param UserPolicy $user
     * @param CarModel $car_model
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CarModel $car_model)
    {
        return $car_model->user_id == user_id() && $car_model->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given car_model.
     *
     * @param UserPolicy $user
     * @param CarModel $car_model
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CarModel $car_model)
    {
        if ($user->canDo('automobile.car_model.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given car_model.
     *
     * @param UserPolicy $user
     * @param CarModel $car_model
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CarModel $car_model)
    {
        if ($user->canDo('automobile.car_model.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
